package token

import (
	"github.com/ethereum/go-ethereum/common"
)

type store interface {
	GetTokens() []*Token
	GetVersion() string
	GetSource() string
	GetName() string
	GetUpdatedAt() int64
}

var tokenPeg = map[string]string{
	"aUSDC": "USD",
	"DAI":   "USD",
	"SAI":   "USD",
	"sUSD":  "USD",
	"PAXG":  "XAU",
	"TCAD":  "CAD",
	"TUSD":  "USD",
	"TGBP":  "GBP",
	"TAUD":  "AUD",
	"USDC":  "USD",
	"USDD":  "USD",
	"USDS":  "USD",
	"USDT":  "USD",
	"USDP":  "USD",
}

func GetTokenPegSymbol(symbol string) string {
	return tokenPeg[symbol]
}

type DefaultStore struct {
	TokenListID []*Token
}

func (s *DefaultStore) GetName() string {
	return "Status Token List"
}

func (s *DefaultStore) GetVersion() string {
	return "1.0.0"
}

func (s *DefaultStore) GetUpdatedAt() int64 {
	return 1697613003
}

func (s *DefaultStore) GetSource() string {
	return "https://github.com/status-im/status-go/blob/develop/services/wallet/token/tokenstore.go"
}

func newDefaultStore() *DefaultStore {
	return &DefaultStore{
		TokenListID: []*Token{
			&Token{
				Address:     common.HexToAddress("0x6b175474e89094c44da98b954eedeac495271d0f"),
				Name:        "Dai Stablecoin",
				Symbol:      "DAI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359"),
				Name:        "Sai Stablecoin v1.0",
				Symbol:      "SAI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x9f8f72aa9304c8b593d555f12ef6589cc3a579a2"),
				Name:        "MKR",
				Symbol:      "MKR",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x86fa049857e0209aa7d9e616f7eb3b3b78ecfdb0"),
				Name:        "EOS",
				Symbol:      "EOS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xd26114cd6ee289accf82350c8d8487fedb8a0c07"),
				Name:        "OMGToken",
				Symbol:      "OMG",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xd4fa1460f537bb9085d22c7bccb5dd450ef28e3a"),
				Name:        "Populous Platform",
				Symbol:      "PPT",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1985365e9f78359a9b6ad760e32412f4a445e862"),
				Name:        "Reputation",
				Symbol:      "REP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x595832f8fc6bf59c85c527fec3740a1b7a361269"),
				Name:        "PowerLedger",
				Symbol:      "POWR",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb97048628db6b661d4c2aa833e95dbe1a905b280"),
				Name:        "TenX Pay Token",
				Symbol:      "PAY",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x92e78dae1315067a8819efd6dca432de9dcde2e9"),
				Name:        "Veros",
				Symbol:      "VRS",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xa74476443119a942de498590fe1f2454d7d4ac0d"),
				Name:        "Golem Network Token",
				Symbol:      "GNT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4156d3342d5c385a87d264f90653733592000581"),
				Name:        "Salt",
				Symbol:      "SALT",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb8c77482e45f1f44de1745f52c74426c631bdd52"),
				Name:        "BNB",
				Symbol:      "BNB",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0d8775f648430679a709e98d2b0cb6250d2887ef"),
				Name:        "Basic Attention Token",
				Symbol:      "BAT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xdd974d5c2e2928dea5f71b9825b8b646686bd200"),
				Name:        "Kyber Network Crystal",
				Symbol:      "KNC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb683D83a532e2Cb7DFa5275eED3698436371cc9f"),
				Name:        "BTU Protocol",
				Symbol:      "BTU",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xe0b7927c4af23765cb51314a0e0521a9645f0e2a"),
				Name:        "Digix DAO",
				Symbol:      "DGD",
				Decimals:    9,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x5ca9a71b1d01849c0a95490cc00559717fcf0d1d"),
				Name:        "Aeternity",
				Symbol:      "AE",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf230b790e05390fc8295f4d3f60332c93bed42e2"),
				Name:        "Tronix",
				Symbol:      "TRX",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x255aa6df07540cb5d3d297f0d0d4d84cb52bc8e6"),
				Name:        "Raiden Token",
				Symbol:      "RDN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x744d70fdbe2ba4cf95131626614a1763df805b9e"),
				Name:        "Status Network Token",
				Symbol:      "SNT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xaec2e87e0a235266d9c5adc9deb4b2e29b54d009"),
				Name:        "SingularDTV",
				Symbol:      "SNGLS",
				Decimals:    0,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6810e776880c02933d47db1b9fc05908e5386b96"),
				Name:        "Gnosis Token",
				Symbol:      "GNO",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb64ef51c888972c908cfacf59b47c1afbc0ab8ac"),
				Name:        "StorjToken",
				Symbol:      "STORJ",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4470bb87d77b963a013db939be332f927f2b992e"),
				Name:        "AdEx",
				Symbol:      "ADX",
				Decimals:    4,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x419d0d8bdd9af5e606ae2232ed285aff190e711b"),
				Name:        "FunFair",
				Symbol:      "FUN",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x41e5560054824ea6b0732e656e3ad64e20e94e45"),
				Name:        "Civic",
				Symbol:      "CVC",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x888666ca69e0f178ded6d75b5726cee99a87d698"),
				Name:        "ICONOMI",
				Symbol:      "ICN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb7cb1c96db6b22b0d3d9536e0108d062bd488f74"),
				Name:        "Walton Token",
				Symbol:      "WTC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xcb97e65f07da24d46bcdd078ebebd7c6e6e3d750"),
				Name:        "Bytom",
				Symbol:      "BTM",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xe41d2489571d322189246dafa5ebde1f4699f498"),
				Name:        "0x Protocol Token",
				Symbol:      "ZRX",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1f573d6fb3f13d689ff844b4ce37794d79a7ff1c"),
				Name:        "Bancor Network Token",
				Symbol:      "BNT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf433089366899d83a9f26a773d59ec7ecf30355e"),
				Name:        "Metal",
				Symbol:      "MTL",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xc42209accc14029c1012fb5680d95fbd6036e2a0"),
				Name:        "PayPie",
				Symbol:      "PPP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x514910771af9ca656af840dff83e8264ecf986ca"),
				Name:        "ChainLink Token",
				Symbol:      "LINK",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x818fc6c2ec5986bc6e2cbf00939d90556ab12ce5"),
				Name:        "Kin",
				Symbol:      "KIN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x960b236a07cf122663c4303350609a66a7b288c0"),
				Name:        "Aragon Network Token",
				Symbol:      "ANT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x40395044ac3c0c57051906da938b54bd6557f212"),
				Name:        "MobileGo Token",
				Symbol:      "MGO",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb63b606ac810a52cca15e44bb630fd42d8d1d83d"),
				Name:        "Monaco",
				Symbol:      "MCO",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xbbbbca6a901c926f240b89eacb641d8aec7aeafd"),
				Name:        "LoopringCoin V2",
				Symbol:      "LRC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7a41e0517a5eca4fdbc7fbeba4d4c47b9ff6dc63"),
				Name:        "Zeus Shield Coin",
				Symbol:      "ZSC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0cf0ee63788a0849fe5297f3407f701e122cc023"),
				Name:        "Streamr (old)",
				Symbol:      "XDATA",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf970b8e36e23f7fc3fd752eea86f8be8d83375a6"),
				Name:        "Ripio Credit Network Token",
				Symbol:      "RCN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x667088b212ce3d06a1b553a7221e1fd19000d9af"),
				Name:        "WINGS",
				Symbol:      "WINGS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x08711d3b02c8758f2fb3ab4e80228418a7f8e39c"),
				Name:        "Edgeless",
				Symbol:      "EDG",
				Decimals:    0,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xbeb9ef514a379b997e0798fdcc901ee474b6d9a1"),
				Name:        "Melon Token",
				Symbol:      "MLN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x51db5ad35c671a87207d88fc11d593ac0c8415bd"),
				Name:        "Moeda Loyalty Points",
				Symbol:      "MDA",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xe3818504c1b32bf1557b16c238b2e01fd3149c17"),
				Name:        "PILLAR",
				Symbol:      "PLR",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x697beac28b09e122c4332d163985e8a73121b97f"),
				Name:        "QRL",
				Symbol:      "QRL",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x957c30ab0426e0c93cd8241e2c60392d08c6ac8e"),
				Name:        "Modum Token",
				Symbol:      "MOD",
				Decimals:    0,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xe7775a6e9bcf904eb39da2b68c5efb4f9360e08c"),
				Name:        "Token-as-a-Service",
				Symbol:      "TAAS",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x12b19d3e2ccc14da04fae33e63652ce469b3f2fd"),
				Name:        "GRID Token",
				Symbol:      "GRID",
				Decimals:    12,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7c5a0ce9267ed19b22f8cae653f198e3e8daf098"),
				Name:        "SANtiment network token",
				Symbol:      "SAN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x983f6d60db79ea8ca4eb9968c6aff8cfa04b3c63"),
				Name:        "SONM Token",
				Symbol:      "SNM",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8f8221afbb33998d8584a2b05749ba73c37a938a"),
				Name:        "Request Token",
				Symbol:      "REQ",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x12480e24eb5bec1a9d4369cab6a80cad3c0a377a"),
				Name:        "Substratum",
				Symbol:      "SUB",
				Decimals:    2,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0f5d2fb29fb7d3cfee444a200298f468908cc942"),
				Name:        "Decentraland MANA",
				Symbol:      "MANA",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x27054b13b1b798b345b591a4d22e6562d47ea75a"),
				Name:        "AirSwap Token",
				Symbol:      "AST",
				Decimals:    4,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x48f775efbe4f5ece6e0df2f7b5932df56823b990"),
				Name:        "R token",
				Symbol:      "R",
				Decimals:    0,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xaf30d2a7e90d7dc361c8c4585e9bb7d2f6f15bc7"),
				Name:        "FirstBlood Token",
				Symbol:      "1ST",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x12fef5e57bf45873cd9b62e9dbd7bfb99e32d73e"),
				Name:        "Cofoundit",
				Symbol:      "CFI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf0ee6b27b759c9893ce4f094b49ad28fd15a23e4"),
				Name:        "Enigma",
				Symbol:      "ENG",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4dc3643dbc642b72c158e7f3d2ff232df61cb6ce"),
				Name:        "Amber Token",
				Symbol:      "AMB",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x90528aeb3a2b736b780fd1b6c478bb7e1d643170"),
				Name:        "XPlay Token",
				Symbol:      "XPA",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x881ef48211982d01e2cb7092c915e647cd40d85c"),
				Name:        "Open Trading Network",
				Symbol:      "OTN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xcb94be6f13a1182e4a4b6140cb7bf2025d28e41b"),
				Name:        "Trustcoin",
				Symbol:      "TRST",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xaaaf91d9b90df800df4f55c205fd6989c977e73a"),
				Name:        "Monolith TKN",
				Symbol:      "TKN",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x168296bb09e24a88805cb9c33356536b980d3fc5"),
				Name:        "RHOC",
				Symbol:      "RHOC",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xac3da587eac229c9896d919abc235ca4fd7f72c1"),
				Name:        "Target Coin",
				Symbol:      "TGT",
				Decimals:    1,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf3db5fa2c66b7af3eb0c0b782510816cbe4813b8"),
				Name:        "Everex",
				Symbol:      "EVX",
				Decimals:    4,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x014b50466590340d41307cc54dcee990c8d58aa8"),
				Name:        "ICOS",
				Symbol:      "ICOS",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0abdace70d3790235af448c88547603b945604ea"),
				Name:        "district0x Network Token",
				Symbol:      "DNT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x08d32b0da63e2c3bcf8019c9c5d849d7a9d791e6"),
				Name:        "Dentacoin",
				Symbol:      "DCN",
				Decimals:    0,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xced4e93198734ddaff8492d525bd258d49eb388e"),
				Name:        "Eidoo Token",
				Symbol:      "EDO",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x29d75277ac7f0335b2165d0895e8725cbf658d73"),
				Name:        "BitDice",
				Symbol:      "CSNO",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xb2f7eb1f2c37645be61d73953035360e768d81e6"),
				Name:        "Cobinhood Token",
				Symbol:      "COB",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf629cbd94d3791c9250152bd8dfbdf380e2a3b9c"),
				Name:        "Enjin Coin",
				Symbol:      "ENJ",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0d88ed6e74bbfd96b831231638b66c05571e824f"),
				Name:        "AVENTUS",
				Symbol:      "AVT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6531f133e6deebe7f2dce5a0441aa7ef330b4e53"),
				Name:        "Chronobank TIME",
				Symbol:      "TIME",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xd4c435f5b09f855c3317c8524cb1f586e42795fa"),
				Name:        "Cindicator Token",
				Symbol:      "CND",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x006bea43baa3f7a6f765f14f10a1a1b08334ef45"),
				Name:        "Stox",
				Symbol:      "STX",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4df812f6064def1e5e029f1ca858777cc98d2d81"),
				Name:        "Xaurum",
				Symbol:      "XAUR",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2c974b2d0ba1716e644c1fc59982a89ddd2ff724"),
				Name:        "Vibe",
				Symbol:      "VIB",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7728dfef5abd468669eb7f9b48a7f70a501ed29d"),
				Name:        "PRG",
				Symbol:      "PRG",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6c2adc2073994fb2ccc5032cc2906fa221e9b391"),
				Name:        "Delphy Token",
				Symbol:      "DPY",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2fe6ab85ebbf7776fee46d191ee4cea322cecf51"),
				Name:        "CoinDash Token",
				Symbol:      "CDT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x08f5a9235b08173b7569f83645d2c7fb55e8ccd8"),
				Name:        "Tierion Network Token",
				Symbol:      "TNT",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x9af4f26941677c706cfecf6d3379ff01bb85d5ab"),
				Name:        "DomRaiderToken",
				Symbol:      "DRT",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x42d6622dece394b54999fbd73d108123806f6a18"),
				Name:        "SPANK",
				Symbol:      "SPANK",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x80046305aaab08f6033b56a360c184391165dc2d"),
				Name:        "Berlin Coin",
				Symbol:      "BRLN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x58b6a8a3302369daec383334672404ee733ab239"),
				Name:        "Livepeer Token",
				Symbol:      "LPT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2c4e8f2d746113d0696ce89b35f0d8bf88e0aeca"),
				Name:        "Simple Token",
				Symbol:      "ST",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2260fac5e5542a773aa44fbcfedf7c193bc2c599"),
				Name:        "Wrapped BTC",
				Symbol:      "WBTC",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x107c4504cd79c5d2696ea0030a8dd4e92601b82e"),
				Name:        "Bloom Token",
				Symbol:      "BLT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4575f41308EC1483f3d399aa9a2826d74Da13Deb"),
				Name:        "Orchid",
				Symbol:      "OXT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x96a65609a7b84e8842732deb08f56c3e21ac6f8a"),
				Name:        "Centra token",
				Symbol:      "Centra",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2e071d2966aa7d8decb1005885ba1977d6038a65"),
				Name:        "DICE",
				Symbol:      "ROL",
				Decimals:    16,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x9b11efcaaa1890f6ee52c6bb7cf8153ac5d74139"),
				Name:        "Attention Token of Media",
				Symbol:      "ATM",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x99ea4dB9EE77ACD40B119BD1dC4E33e1C070b80d"),
				Name:        "Quantstamp Token",
				Symbol:      "QSP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x80fB784B7eD66730e8b1DBd9820aFD29931aab03"),
				Name:        "EthLend Token",
				Symbol:      "LEND",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xA15C7Ebe1f07CaF6bFF097D8a589fb8AC49Ae5B3"),
				Name:        "Pundi X Token",
				Symbol:      "NPXS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xA4e8C3Ec456107eA67d3075bF9e3DF3A75823DB0"),
				Name:        "LoomToken",
				Symbol:      "LOOM",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0e0989b1f9B8A38983c2BA8053269Ca62Ec9B195"),
				Name:        "Po.et",
				Symbol:      "POE",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x5732046A883704404F284Ce41FfADd5b007FD668"),
				Name:        "Bluzelle Token",
				Symbol:      "BLZ",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xFA1a856Cfa3409CFa145Fa4e20Eb270dF3EB21ab"),
				Name:        "IOSToken",
				Symbol:      "IOST",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1776e1F26f98b1A5dF9cD347953a26dd3Cb46671"),
				Name:        "Numeraire",
				Symbol:      "NMR",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8E870D67F660D95d5be530380D0eC0bd388289E1"),
				Name:        "Pax Dollar",
				Symbol:      "USDP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xEA26c4aC16D4a5A106820BC8AEE85fd0b7b2b664"),
				Name:        "QuarkChain Token",
				Symbol:      "QKC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x45804880De22913dAFE09f4980848ECE6EcbAf78"),
				Name:        "Paxos Gold",
				Symbol:      "PAXG",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x865ec58b06bF6305B886793AA20A2da31D034E68"),
				Name:        "Moss Coin",
				Symbol:      "MOC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x408e41876cCCDC0F92210600ef50372656052a38"),
				Name:        "Republic Token",
				Symbol:      "REN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x607F4C5BB672230e8672085532f7e901544a7375"),
				Name:        "iEx.ec Network Token",
				Symbol:      "RLC",
				Decimals:    9,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8400D94A5cb0fa0D041a3788e395285d61c9ee5e"),
				Name:        "UniBright",
				Symbol:      "UBT",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4f3AfEC4E5a3F2A6a1A411DEF7D7dFe50eE057bF"),
				Name:        "Digix Gold Token",
				Symbol:      "DGX",
				Decimals:    9,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xEA38eAa3C86c8F9B751533Ba2E562deb9acDED40"),
				Name:        "Fuel Token",
				Symbol:      "FUEL",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x00000100F2A2bd000715001920eB70D229700085"),
				Name:        "TrueCAD",
				Symbol:      "TCAD",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6710c63432A2De02954fc0f851db07146a6c0312"),
				Name:        "SyncFab Smart Manufacturing Blockchain",
				Symbol:      "MFG",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x543Ff227F64Aa17eA132Bf9886cAb5DB55DCAddf"),
				Name:        "DAOstack",
				Symbol:      "GEN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0E8d6b471e332F140e7d9dbB99E5E3822F728DA6"),
				Name:        "ABYSS",
				Symbol:      "ABYSS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xB62132e35a6c13ee1EE0f84dC5d40bad8d815206"),
				Name:        "Nexo",
				Symbol:      "NEXO",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x0000000000085d4780B73119b644AE5ecd22b376"),
				Name:        "TrueUSD",
				Symbol:      "TUSD",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xD0a4b8946Cb52f0661273bfbC6fD0E0C75Fc6433"),
				Name:        "Storm Token",
				Symbol:      "STORM",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xaF4DcE16Da2877f8c9e00544c93B62Ac40631F16"),
				Name:        "Monetha",
				Symbol:      "MTH",
				Decimals:    5,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x00000000441378008EA67F4284A57932B1c000a5"),
				Name:        "TrueGBP",
				Symbol:      "TGBP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xbf2179859fc6D5BEE9Bf9158632Dc51678a4100e"),
				Name:        "ELF Token",
				Symbol:      "ELF",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x9992eC3cF6A55b00978cdDF2b27BC6882d88D1eC"),
				Name:        "Polymath",
				Symbol:      "POLY",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x20F7A3DdF244dc9299975b4Da1C39F8D5D75f05A"),
				Name:        "Sapien Network",
				Symbol:      "SPN",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1a7a8BD9106F2B8D977E08582DC7d24c723ab0DB"),
				Name:        "AppCoins",
				Symbol:      "APPC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xdAC17F958D2ee523a2206206994597C13D831ec7"),
				Name:        "Tether USD",
				Symbol:      "USDT",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xa3d58c4E56fedCae3a7c43A725aeE9A71F0ece4e"),
				Name:        "Metronome",
				Symbol:      "MET",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6f259637dcD74C767781E37Bc6133cd6A68aa161"),
				Name:        "HuobiToken",
				Symbol:      "HT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2"),
				Name:        "Wrapped Ether",
				Symbol:      "WETH",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8f3470A7388c05eE4e7AF3d01D8C722b0FF52374"),
				Name:        "Veritaseum",
				Symbol:      "VERI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x00006100F7090010005F1bd7aE6122c3C2CF0090"),
				Name:        "TrueAUD",
				Symbol:      "TAUD",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x66497A283E0a007bA3974e837784C6AE323447de"),
				Name:        "PornToken",
				Symbol:      "PT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xB24754bE79281553dc1adC160ddF5Cd9b74361a4"),
				Name:        "RIALTO",
				Symbol:      "XRL",
				Decimals:    9,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F"),
				Name:        "Synthetix Network Token",
				Symbol:      "SNX",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x07e3c70653548B04f0A75970C1F81B4CBbFB606f"),
				Name:        "Delta",
				Symbol:      "DLT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8207c1FfC5B6804F6024322CcF34F29c3541Ae26"),
				Name:        "OriginToken",
				Symbol:      "OGN",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x554C20B7c486beeE439277b4540A434566dC4C02"),
				Name:        "Decision Token",
				Symbol:      "HST",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x286BDA1413a2Df81731D4930ce2F862a35A609fE"),
				Name:        "WaBi",
				Symbol:      "WaBi",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xE5a3229CCb22b6484594973A03a3851dCd948756"),
				Name:        "RAE Token",
				Symbol:      "RAE",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x24692791Bc444c5Cd0b81e3CBCaba4b04Acd1F3B"),
				Name:        "UnikoinGold",
				Symbol:      "UKG",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xD46bA6D942050d489DBd938a2C909A5d5039A161"),
				Name:        "Ampleforth",
				Symbol:      "AMPL",
				Decimals:    9,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xA4Bdb11dc0a2bEC88d24A3aa1E6Bb17201112eBe"),
				Name:        "StableUSD",
				Symbol:      "USDS",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xB98d4C97425d9908E66E53A6fDf673ACcA0BE986"),
				Name:        "ArcBlock",
				Symbol:      "ABT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x81c9151de0C8bafCd325a57E3dB5a5dF1CEBf79c"),
				Name:        "Datum Token",
				Symbol:      "DAT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xa6a840E50bCaa50dA017b91A0D86B8b2d41156EE"),
				Name:        "EchoLink",
				Symbol:      "EKO",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4a57E687b9126435a9B19E4A802113e266AdeBde"),
				Name:        "Flexacoin",
				Symbol:      "FXC",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xC86D054809623432210c107af2e3F619DcFbf652"),
				Name:        "SENTINEL PROTOCOL",
				Symbol:      "UPP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x5Af2Be193a6ABCa9c8817001F45744777Db30756"),
				Name:        "Voyager",
				Symbol:      "VGX",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x69b148395ce0015c13e36bffbad63f49ef874e03"),
				Name:        "Data Token",
				Symbol:      "DTA",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x57Ab1ec28D129707052df4dF418D58a2D46d5f51"),
				Name:        "Synth sUSD",
				Symbol:      "sUSD",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x5d3a536E4D6DbD6114cc1Ead35777bAB948E3643"),
				Name:        "Compound Dai",
				Symbol:      "cDAI",
				Decimals:    8,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xba11d00c5f74255f56a5e366f4f77f5a186d7f55"),
				Name:        "BandToken",
				Symbol:      "BAND",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xa7fc5d2453e3f68af0cc1b78bcfee94a1b293650"),
				Name:        "Spiking",
				Symbol:      "SPIKE",
				Decimals:    10,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984"),
				Name:        "Uniswap",
				Symbol:      "UNI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xc00e94cb662c3520282e6f5717214004a7f26888"),
				Name:        "Compound",
				Symbol:      "COMP",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xba100000625a3754423978a60c9317c58a424e3d"),
				Name:        "Balancer",
				Symbol:      "BAL",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x8ab7404063ec4dbcfd4598215992dc3f8ec853d7"),
				Name:        "Akropolis",
				Symbol:      "AKRO",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x9ba00d6856a4edf4665bca2c2309936572473b7e"),
				Name:        "Aave Interest bearing USDC",
				Symbol:      "aUSDC",
				Decimals:    6,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xc944e90c64b2c07662a292be6244bdf05cda44a7"),
				Name:        "Graph Token",
				Symbol:      "GRT",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7DD9c5Cba05E151C895FDe1CF355C9A1D5DA6429"),
				Name:        "Golem Network Token",
				Symbol:      "GLM",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x23b608675a2b2fb1890d3abbd85c5775c51691d5"),
				Name:        "Unisocks Edition 0",
				Symbol:      "SOCKS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xEEF9f339514298C6A857EfCfC1A762aF84438dEE"),
				Name:        "Hermez Network Token",
				Symbol:      "HEZ",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xaa6e8127831c9de45ae56bb1b0d4d4da6e5665bd"),
				Name:        "ETH 2x Flexible Leverage Index",
				Symbol:      "ETH2x-FLI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xba5BDe662c17e2aDFF1075610382B9B691296350"),
				Name:        "SuperRare",
				Symbol:      "RARE",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72"),
				Name:        "Ethereum Name Service",
				Symbol:      "ENS",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xDd1Ad9A21Ce722C151A836373baBe42c868cE9a4"),
				Name:        "Universal Basic Income",
				Symbol:      "UBI",
				Decimals:    18,
				ChainID:     1,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xc55cf4b03948d7ebc8b9e8bad92643703811d162"),
				Name:        "Status Test Token",
				Symbol:      "STT",
				Decimals:    18,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xdee43a267e8726efd60c2e7d5b81552dcd4fa35c"),
				Name:        "Handy Test Token",
				Symbol:      "HND",
				Decimals:    0,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x703d7dc0bc8e314d65436adf985dda51e09ad43b"),
				Name:        "Lucky Test Token",
				Symbol:      "LXS",
				Decimals:    2,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xe639e24346d646e927f323558e6e0031bfc93581"),
				Name:        "Adi Test Token",
				Symbol:      "ADI",
				Decimals:    7,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2e7cd05f437eb256f363417fd8f920e2efa77540"),
				Name:        "Wagner Test Token",
				Symbol:      "WGN",
				Decimals:    10,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x57cc9b83730e6d22b224e9dc3e370967b44a2de0"),
				Name:        "Modest Test Token",
				Symbol:      "MDS",
				Decimals:    18,
				ChainID:     3,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x6ba7dc8dd10880ab83041e60c4ede52bb607864b"),
				Name:        "Moksha Coin",
				Symbol:      "MOKSHA",
				Decimals:    18,
				ChainID:     4,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7d4ccf6af2f0fdad48ee7958bcc28bdef7b732c7"),
				Name:        "WIBB",
				Symbol:      "WIBB",
				Decimals:    18,
				ChainID:     4,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x43d5adc3b49130a575ae6e4b00dfa4bc55c71621"),
				Name:        "Status Test Token",
				Symbol:      "STT",
				Decimals:    18,
				ChainID:     4,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x3d6afaa395c31fcd391fe3d562e75fe9e8ec7e6a"),
				Name:        "Status Test Token",
				Symbol:      "STT",
				Decimals:    18,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x98339d8c260052b7ad81c28c16c0b98420f2b46a"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x022e292b44b5a146f2e8ee36ff44d3dd863c915c"),
				Name:        "Xeenus 💪",
				Symbol:      "XEENUS",
				Decimals:    18,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xc6fde3fd2cc2b173aec24cc3f267cb3cd78a26b7"),
				Name:        "Yeenus 💪",
				Symbol:      "YEENUS",
				Decimals:    8,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x1f9061b953bba0e36bf50f21876132dcf276fc6e"),
				Name:        "Zeenus 💪",
				Symbol:      "ZEENUS",
				Decimals:    0,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf4B2cbc3bA04c478F0dC824f4806aC39982Dce73"),
				Name:        "Tether USD",
				Symbol:      "USDT",
				Decimals:    6,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf2edF1c091f683E3fb452497d9a98A49cBA84666"),
				Name:        "DAI Stablecoin",
				Symbol:      "DAI",
				Decimals:    18,
				ChainID:     5,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x7f5c764cbc14f9669b88837ca1490cca17c31607"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     10,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x3e50bf6703fc132a94e4baff068db2055655f11b"),
				Name:        "buffiDai",
				Symbol:      "BUFF",
				Decimals:    18,
				ChainID:     100,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xcb4ceefce514b2d910d3ac529076d18e3add3775"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     420,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xfd086bc7cd5c481dcc9c85ebe478a1c0b69fcbb9"),
				Name:        "Tether USD",
				Symbol:      "USDT",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xff970a61a04b1ca14834a43f5de4533ebddb5cc8"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xda10009cbd5d07dd0cecc66161fc93d7c9000da1"),
				Name:        "DAI Stablecoin",
				Symbol:      "DAI",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x2f2a2543b76a4166549f7aab2e75bef0aefc5b0f"),
				Name:        "Wrapped BTC",
				Symbol:      "WBTC",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xfa7f8980b0f1e64a2062791cc3b0871572f1f7f0"),
				Name:        "Uniswap",
				Symbol:      "UNI",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0xf97f4df75117a78c1a5a0dbb814af92458539fb4"),
				Name:        "ChainLink Token",
				Symbol:      "Link",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x17fc002b466eec40dae837fc4be5c67993ddbd6f"),
				Name:        "Frax",
				Symbol:      "FRAX",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x4d15a3a2286d883af0aa1b3f21367843fac63e07"),
				Name:        "True USD",
				Symbol:      "TUSD",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x23a941036ae778ac51ab04cea08ed6e2fe103614"),
				Name:        "Graph Token",
				Symbol:      "GRT",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x680447595e8b7b3aa1b43beb9f6098c79ac2ab3f"),
				Name:        "Decentralized USD",
				Symbol:      "USDD",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x11cdb42b0eb46d95f990bedd4695a6e3fa034978"),
				Name:        "Curve DAO Token",
				Symbol:      "CRV",
				Decimals:    18,
				ChainID:     42161,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x17078F231AA8dc256557b49a8f2F72814A71f633"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     421613,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x265B25e22bcd7f10a5bD6E6410F10537Cc7567e8"),
				Name:        "Tether USD",
				Symbol:      "USDT",
				Decimals:    6,
				ChainID:     421613,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x3e622317f8c93f7328350cf0b56d9ed4c620c5d6"),
				Name:        "Dai Stablecoin",
				Symbol:      "DAI",
				Decimals:    18,
				ChainID:     11155111,
				TokenListID: "status",
			},
			&Token{
				Address:     common.HexToAddress("0x44a739916D41eC0226d98F83BE5364B69078DA41"),
				Name:        "USD Coin",
				Symbol:      "USDC",
				Decimals:    6,
				ChainID:     421614,
				TokenListID: "status",
			},
		},
	}
}

func (s *DefaultStore) GetTokens() []*Token {
	return s.TokenListID
}
